/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Details about a resource which is being promoted.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ActivityContentDetailsPromotedItem extends GenericJson {

  /**
   * The URL the client should fetch to request a promoted item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String adTag;

  /**
   * The URL the client should ping to indicate that the user clicked through on this promoted item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String clickTrackingUrl;

  /**
   * The URL the client should ping to indicate that the user was shown this promoted item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String creativeViewUrl;

  /**
   * The type of call-to-action, a message to the user indicating action that can be taken.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String ctaType;

  /**
   * The text description to accompany the promoted item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String descriptionText;

  /**
   * The URL the client should direct the user to, if the user chooses to visit the advertiser's
   * website.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String destinationUrl;

  /**
   * The ID that YouTube uses to uniquely identify the promoted video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String videoId;

  /**
   * The URL the client should fetch to request a promoted item.
   * The value returned may be {@code null}.
   */
  public String getAdTag() {
    return adTag;
  }

  /**
   * The URL the client should fetch to request a promoted item.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setAdTag(String adTag) {
    this.adTag = adTag;
    return this;
  }

  /**
   * The URL the client should ping to indicate that the user clicked through on this promoted item.
   * The value returned may be {@code null}.
   */
  public String getClickTrackingUrl() {
    return clickTrackingUrl;
  }

  /**
   * The URL the client should ping to indicate that the user clicked through on this promoted item.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setClickTrackingUrl(String clickTrackingUrl) {
    this.clickTrackingUrl = clickTrackingUrl;
    return this;
  }

  /**
   * The URL the client should ping to indicate that the user was shown this promoted item.
   * The value returned may be {@code null}.
   */
  public String getCreativeViewUrl() {
    return creativeViewUrl;
  }

  /**
   * The URL the client should ping to indicate that the user was shown this promoted item.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setCreativeViewUrl(String creativeViewUrl) {
    this.creativeViewUrl = creativeViewUrl;
    return this;
  }

  /**
   * The type of call-to-action, a message to the user indicating action that can be taken.
   * The value returned may be {@code null}.
   */
  public String getCtaType() {
    return ctaType;
  }

  /**
   * The type of call-to-action, a message to the user indicating action that can be taken.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setCtaType(String ctaType) {
    this.ctaType = ctaType;
    return this;
  }

  /**
   * The text description to accompany the promoted item.
   * The value returned may be {@code null}.
   */
  public String getDescriptionText() {
    return descriptionText;
  }

  /**
   * The text description to accompany the promoted item.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setDescriptionText(String descriptionText) {
    this.descriptionText = descriptionText;
    return this;
  }

  /**
   * The URL the client should direct the user to, if the user chooses to visit the advertiser's
   * website.
   * The value returned may be {@code null}.
   */
  public String getDestinationUrl() {
    return destinationUrl;
  }

  /**
   * The URL the client should direct the user to, if the user chooses to visit the advertiser's
   * website.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setDestinationUrl(String destinationUrl) {
    this.destinationUrl = destinationUrl;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the promoted video.
   * The value returned may be {@code null}.
   */
  public String getVideoId() {
    return videoId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the promoted video.
   * The value set may be {@code null}.
   */
  public ActivityContentDetailsPromotedItem setVideoId(String videoId) {
    this.videoId = videoId;
    return this;
  }

}
