/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Basic details about an activity, including title, description, thumbnails, activity type and
 * group.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class ActivitySnippet extends GenericJson {

  /**
   * The ID that YouTube uses to uniquely identify the channel associated with the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * Channel title for the channel responsible for this activity
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelTitle;

  /**
   * The description of the resource primarily associated with the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The group ID associated with the activity. A group ID identifies user events that are
   * associated with the same user and resource. For example, if a user rates a video and marks the
   * same video as a favorite, the entries for those events would have the same group ID in the
   * user's activity feed. In your user interface, you can avoid repetition by grouping events with
   * the same groupId value.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String groupId;

  /**
   * The date and time that the video was uploaded. The value is specified in ISO 8601 (YYYY-MM-
   * DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime publishedAt;

  /**
   * A map of thumbnail images associated with the resource that is primarily associated with the
   * activity. For each object in the map, the key is the name of the thumbnail image, and the value
   * is an object that contains other information about the thumbnail.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ThumbnailDetails thumbnails;

  /**
   * The title of the resource primarily associated with the activity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The type of activity that the resource describes.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * The ID that YouTube uses to uniquely identify the channel associated with the activity.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the channel associated with the activity.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * Channel title for the channel responsible for this activity
   * The value returned may be {@code null}.
   */
  public String getChannelTitle() {
    return channelTitle;
  }

  /**
   * Channel title for the channel responsible for this activity
   * The value set may be {@code null}.
   */
  public ActivitySnippet setChannelTitle(String channelTitle) {
    this.channelTitle = channelTitle;
    return this;
  }

  /**
   * The description of the resource primarily associated with the activity.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The description of the resource primarily associated with the activity.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The group ID associated with the activity. A group ID identifies user events that are
   * associated with the same user and resource. For example, if a user rates a video and marks the
   * same video as a favorite, the entries for those events would have the same group ID in the
   * user's activity feed. In your user interface, you can avoid repetition by grouping events with
   * the same groupId value.
   * The value returned may be {@code null}.
   */
  public String getGroupId() {
    return groupId;
  }

  /**
   * The group ID associated with the activity. A group ID identifies user events that are
   * associated with the same user and resource. For example, if a user rates a video and marks the
   * same video as a favorite, the entries for those events would have the same group ID in the
   * user's activity feed. In your user interface, you can avoid repetition by grouping events with
   * the same groupId value.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setGroupId(String groupId) {
    this.groupId = groupId;
    return this;
  }

  /**
   * The date and time that the video was uploaded. The value is specified in ISO 8601 (YYYY-MM-
   * DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublishedAt() {
    return publishedAt;
  }

  /**
   * The date and time that the video was uploaded. The value is specified in ISO 8601 (YYYY-MM-
   * DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setPublishedAt(DateTime publishedAt) {
    this.publishedAt = publishedAt;
    return this;
  }

  /**
   * A map of thumbnail images associated with the resource that is primarily associated with the
   * activity. For each object in the map, the key is the name of the thumbnail image, and the value
   * is an object that contains other information about the thumbnail.
   * The value returned may be {@code null}.
   */
  public ThumbnailDetails getThumbnails() {
    return thumbnails;
  }

  /**
   * A map of thumbnail images associated with the resource that is primarily associated with the
   * activity. For each object in the map, the key is the name of the thumbnail image, and the value
   * is an object that contains other information about the thumbnail.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setThumbnails(ThumbnailDetails thumbnails) {
    this.thumbnails = thumbnails;
    return this;
  }

  /**
   * The title of the resource primarily associated with the activity.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of the resource primarily associated with the activity.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * The type of activity that the resource describes.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * The type of activity that the resource describes.
   * The value set may be {@code null}.
   */
  public ActivitySnippet setType(String type) {
    this.type = type;
    return this;
  }

}
