/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Brief description of the live stream cdn settings.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CdnSettings extends GenericJson {

  /**
   * The format of the video stream that you are sending to Youtube.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String format;

  /**
   * The ingestionInfo object contains information that YouTube provides that you need to transmit
   * your RTMP or HTTP stream to YouTube.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private IngestionInfo ingestionInfo;

  /**
   * The method or protocol used to transmit the video stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String ingestionType;

  /**
   * The format of the video stream that you are sending to Youtube.
   * The value returned may be {@code null}.
   */
  public String getFormat() {
    return format;
  }

  /**
   * The format of the video stream that you are sending to Youtube.
   * The value set may be {@code null}.
   */
  public CdnSettings setFormat(String format) {
    this.format = format;
    return this;
  }

  /**
   * The ingestionInfo object contains information that YouTube provides that you need to transmit
   * your RTMP or HTTP stream to YouTube.
   * The value returned may be {@code null}.
   */
  public IngestionInfo getIngestionInfo() {
    return ingestionInfo;
  }

  /**
   * The ingestionInfo object contains information that YouTube provides that you need to transmit
   * your RTMP or HTTP stream to YouTube.
   * The value set may be {@code null}.
   */
  public CdnSettings setIngestionInfo(IngestionInfo ingestionInfo) {
    this.ingestionInfo = ingestionInfo;
    return this;
  }

  /**
   * The method or protocol used to transmit the video stream.
   * The value returned may be {@code null}.
   */
  public String getIngestionType() {
    return ingestionType;
  }

  /**
   * The method or protocol used to transmit the video stream.
   * The value set may be {@code null}.
   */
  public CdnSettings setIngestionType(String ingestionType) {
    this.ingestionType = ingestionType;
    return this;
  }

}
