/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A channel resource contains information about a YouTube channel.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Channel extends GenericJson {

  /**
   * The brandingSettings object encapsulates information about the branding of the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelBrandingSettings brandingSettings;

  /**
   * The contentDetails object encapsulates information about the channel's content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelContentDetails contentDetails;

  /**
   * The conversionPings object encapsulates information about conversion pings that need to be
   * respected by the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelConversionPings conversionPings;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube uses to uniquely identify the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The invideoPromotion object encapsulates information about promotion campaign associated with
   * the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private InvideoPromotion invideoPromotion;

  /**
   * The kind, fixed to "youtube#channel".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about the channel, such as its title, description,
   * and thumbnail images.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelSnippet snippet;

  /**
   * The statistics object encapsulates statistics for the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelStatistics statistics;

  /**
   * The status object encapsulates information about the privacy status of the channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelStatus status;

  /**
   * The topicDetails object encapsulates information about Freebase topics associated with the
   * channel.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ChannelTopicDetails topicDetails;

  /**
   * The brandingSettings object encapsulates information about the branding of the channel.
   * The value returned may be {@code null}.
   */
  public ChannelBrandingSettings getBrandingSettings() {
    return brandingSettings;
  }

  /**
   * The brandingSettings object encapsulates information about the branding of the channel.
   * The value set may be {@code null}.
   */
  public Channel setBrandingSettings(ChannelBrandingSettings brandingSettings) {
    this.brandingSettings = brandingSettings;
    return this;
  }

  /**
   * The contentDetails object encapsulates information about the channel's content.
   * The value returned may be {@code null}.
   */
  public ChannelContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The contentDetails object encapsulates information about the channel's content.
   * The value set may be {@code null}.
   */
  public Channel setContentDetails(ChannelContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * The conversionPings object encapsulates information about conversion pings that need to be
   * respected by the channel.
   * The value returned may be {@code null}.
   */
  public ChannelConversionPings getConversionPings() {
    return conversionPings;
  }

  /**
   * The conversionPings object encapsulates information about conversion pings that need to be
   * respected by the channel.
   * The value set may be {@code null}.
   */
  public Channel setConversionPings(ChannelConversionPings conversionPings) {
    this.conversionPings = conversionPings;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public Channel setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the channel.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube uses to uniquely identify the channel.
   * The value set may be {@code null}.
   */
  public Channel setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The invideoPromotion object encapsulates information about promotion campaign associated with
   * the channel.
   * The value returned may be {@code null}.
   */
  public InvideoPromotion getInvideoPromotion() {
    return invideoPromotion;
  }

  /**
   * The invideoPromotion object encapsulates information about promotion campaign associated with
   * the channel.
   * The value set may be {@code null}.
   */
  public Channel setInvideoPromotion(InvideoPromotion invideoPromotion) {
    this.invideoPromotion = invideoPromotion;
    return this;
  }

  /**
   * The kind, fixed to "youtube#channel".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#channel".
   * The value set may be {@code null}.
   */
  public Channel setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about the channel, such as its title, description,
   * and thumbnail images.
   * The value returned may be {@code null}.
   */
  public ChannelSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the channel, such as its title, description,
   * and thumbnail images.
   * The value set may be {@code null}.
   */
  public Channel setSnippet(ChannelSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

  /**
   * The statistics object encapsulates statistics for the channel.
   * The value returned may be {@code null}.
   */
  public ChannelStatistics getStatistics() {
    return statistics;
  }

  /**
   * The statistics object encapsulates statistics for the channel.
   * The value set may be {@code null}.
   */
  public Channel setStatistics(ChannelStatistics statistics) {
    this.statistics = statistics;
    return this;
  }

  /**
   * The status object encapsulates information about the privacy status of the channel.
   * The value returned may be {@code null}.
   */
  public ChannelStatus getStatus() {
    return status;
  }

  /**
   * The status object encapsulates information about the privacy status of the channel.
   * The value set may be {@code null}.
   */
  public Channel setStatus(ChannelStatus status) {
    this.status = status;
    return this;
  }

  /**
   * The topicDetails object encapsulates information about Freebase topics associated with the
   * channel.
   * The value returned may be {@code null}.
   */
  public ChannelTopicDetails getTopicDetails() {
    return topicDetails;
  }

  /**
   * The topicDetails object encapsulates information about Freebase topics associated with the
   * channel.
   * The value set may be {@code null}.
   */
  public Channel setTopicDetails(ChannelTopicDetails topicDetails) {
    this.topicDetails = topicDetails;
    return this;
  }

}
