/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for LiveStreamSnippet.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class LiveStreamSnippet extends GenericJson {

  /**
   * The ID that YouTube uses to uniquely identify the channel that is transmitting the stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String channelId;

  /**
   * The stream's description. The value cannot be longer than 10000 characters.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The date and time that the stream was created. The value is specified in ISO 8601 (YYYY-MM-
   * DDThh:mm:ss.sZ) format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime publishedAt;

  /**
   * The stream's title. The value must be between 1 and 128 characters long.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The ID that YouTube uses to uniquely identify the channel that is transmitting the stream.
   * The value returned may be {@code null}.
   */
  public String getChannelId() {
    return channelId;
  }

  /**
   * The ID that YouTube uses to uniquely identify the channel that is transmitting the stream.
   * The value set may be {@code null}.
   */
  public LiveStreamSnippet setChannelId(String channelId) {
    this.channelId = channelId;
    return this;
  }

  /**
   * The stream's description. The value cannot be longer than 10000 characters.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The stream's description. The value cannot be longer than 10000 characters.
   * The value set may be {@code null}.
   */
  public LiveStreamSnippet setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The date and time that the stream was created. The value is specified in ISO 8601 (YYYY-MM-
   * DDThh:mm:ss.sZ) format.
   * The value returned may be {@code null}.
   */
  public DateTime getPublishedAt() {
    return publishedAt;
  }

  /**
   * The date and time that the stream was created. The value is specified in ISO 8601 (YYYY-MM-
   * DDThh:mm:ss.sZ) format.
   * The value set may be {@code null}.
   */
  public LiveStreamSnippet setPublishedAt(DateTime publishedAt) {
    this.publishedAt = publishedAt;
    return this;
  }

  /**
   * The stream's title. The value must be between 1 and 128 characters long.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The stream's title. The value must be between 1 and 128 characters long.
   * The value set may be {@code null}.
   */
  public LiveStreamSnippet setTitle(String title) {
    this.title = title;
    return this;
  }

}
