/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Settings and Info of the monitor stream
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class MonitorStreamInfo extends GenericJson {

  /**
   * If you have set the enableMonitorStream property to true, then this property determines the
   * length of the live broadcast delay.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long broadcastStreamDelayMs;

  /**
   * HTML code that embeds a player that plays the monitor stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String embedHtml;

  /**
   * This value determines whether the monitor stream is enabled for the broadcast. If the monitor
   * stream is enabled, then YouTube will broadcast the event content on a special stream intended
   * only for the broadcaster's consumption. The broadcaster can use the stream to review the event
   * content and also to identify the optimal times to insert cuepoints.
   *
   * You need to set this value to true if you intend to have a broadcast delay for your event.
   *
   * Note: This property cannot be updated once the broadcast is in the testing or live state.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean enableMonitorStream;

  /**
   * If you have set the enableMonitorStream property to true, then this property determines the
   * length of the live broadcast delay.
   * The value returned may be {@code null}.
   */
  public Long getBroadcastStreamDelayMs() {
    return broadcastStreamDelayMs;
  }

  /**
   * If you have set the enableMonitorStream property to true, then this property determines the
   * length of the live broadcast delay.
   * The value set may be {@code null}.
   */
  public MonitorStreamInfo setBroadcastStreamDelayMs(Long broadcastStreamDelayMs) {
    this.broadcastStreamDelayMs = broadcastStreamDelayMs;
    return this;
  }

  /**
   * HTML code that embeds a player that plays the monitor stream.
   * The value returned may be {@code null}.
   */
  public String getEmbedHtml() {
    return embedHtml;
  }

  /**
   * HTML code that embeds a player that plays the monitor stream.
   * The value set may be {@code null}.
   */
  public MonitorStreamInfo setEmbedHtml(String embedHtml) {
    this.embedHtml = embedHtml;
    return this;
  }

  /**
   * This value determines whether the monitor stream is enabled for the broadcast. If the monitor
   * stream is enabled, then YouTube will broadcast the event content on a special stream intended
   * only for the broadcaster's consumption. The broadcaster can use the stream to review the event
   * content and also to identify the optimal times to insert cuepoints.
   *
   * You need to set this value to true if you intend to have a broadcast delay for your event.
   *
   * Note: This property cannot be updated once the broadcast is in the testing or live state.
   * The value returned may be {@code null}.
   */
  public Boolean getEnableMonitorStream() {
    return enableMonitorStream;
  }

  /**
   * This value determines whether the monitor stream is enabled for the broadcast. If the monitor
   * stream is enabled, then YouTube will broadcast the event content on a special stream intended
   * only for the broadcaster's consumption. The broadcaster can use the stream to review the event
   * content and also to identify the optimal times to insert cuepoints.
   *
   * You need to set this value to true if you intend to have a broadcast delay for your event.
   *
   * Note: This property cannot be updated once the broadcast is in the testing or live state.
   * The value set may be {@code null}.
   */
  public MonitorStreamInfo setEnableMonitorStream(Boolean enableMonitorStream) {
    this.enableMonitorStream = enableMonitorStream;
    return this;
  }

}
