/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * A subscription resource contains information about a YouTube user subscription. A subscription
 * notifies a user when new videos are added to a channel or when another user takes one of several
 * actions on YouTube, such as uploading a video, rating a video, or commenting on a video.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Subscription extends GenericJson {

  /**
   * The contentDetails object contains basic statistics about the subscription.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SubscriptionContentDetails contentDetails;

  /**
   * Etag of this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The ID that YouTube uses to uniquely identify the subscription.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The kind, fixed to "youtube#subscription".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The snippet object contains basic details about the subscription, including its title and the
   * channel that the user subscribed to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SubscriptionSnippet snippet;

  /**
   * The subscriberSnippet object contains basic details about the sbuscriber.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SubscriptionSubscriberSnippet subscriberSnippet;

  /**
   * The contentDetails object contains basic statistics about the subscription.
   * The value returned may be {@code null}.
   */
  public SubscriptionContentDetails getContentDetails() {
    return contentDetails;
  }

  /**
   * The contentDetails object contains basic statistics about the subscription.
   * The value set may be {@code null}.
   */
  public Subscription setContentDetails(SubscriptionContentDetails contentDetails) {
    this.contentDetails = contentDetails;
    return this;
  }

  /**
   * Etag of this resource.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * Etag of this resource.
   * The value set may be {@code null}.
   */
  public Subscription setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The ID that YouTube uses to uniquely identify the subscription.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID that YouTube uses to uniquely identify the subscription.
   * The value set may be {@code null}.
   */
  public Subscription setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The kind, fixed to "youtube#subscription".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "youtube#subscription".
   * The value set may be {@code null}.
   */
  public Subscription setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The snippet object contains basic details about the subscription, including its title and the
   * channel that the user subscribed to.
   * The value returned may be {@code null}.
   */
  public SubscriptionSnippet getSnippet() {
    return snippet;
  }

  /**
   * The snippet object contains basic details about the subscription, including its title and the
   * channel that the user subscribed to.
   * The value set may be {@code null}.
   */
  public Subscription setSnippet(SubscriptionSnippet snippet) {
    this.snippet = snippet;
    return this;
  }

  /**
   * The subscriberSnippet object contains basic details about the sbuscriber.
   * The value returned may be {@code null}.
   */
  public SubscriptionSubscriberSnippet getSubscriberSnippet() {
    return subscriberSnippet;
  }

  /**
   * The subscriberSnippet object contains basic details about the sbuscriber.
   * The value set may be {@code null}.
   */
  public Subscription setSubscriberSnippet(SubscriptionSubscriberSnippet subscriberSnippet) {
    this.subscriberSnippet = subscriberSnippet;
    return this;
  }

}
