/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for VideoAgeGating.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoAgeGating extends GenericJson {

  /**
   * Indicates whether or not the video has alcoholic beverage content. Only users of legal
   * purchasing age in a particular country, as identified by ICAP, can view the content.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean alcoholContent;

  /**
   * Age-restricted trailers. For redband trailers and adult-rated video-games. Only users aged 18+
   * can view the content. The the field is true the content is restricted to viewers aged 18+.
   * Otherwise The field won't be present.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean restricted;

  /**
   * Video game rating, if any.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String videoGameRating;

  /**
   * Indicates whether or not the video has alcoholic beverage content. Only users of legal
   * purchasing age in a particular country, as identified by ICAP, can view the content.
   * The value returned may be {@code null}.
   */
  public Boolean getAlcoholContent() {
    return alcoholContent;
  }

  /**
   * Indicates whether or not the video has alcoholic beverage content. Only users of legal
   * purchasing age in a particular country, as identified by ICAP, can view the content.
   * The value set may be {@code null}.
   */
  public VideoAgeGating setAlcoholContent(Boolean alcoholContent) {
    this.alcoholContent = alcoholContent;
    return this;
  }

  /**
   * Age-restricted trailers. For redband trailers and adult-rated video-games. Only users aged 18+
   * can view the content. The the field is true the content is restricted to viewers aged 18+.
   * Otherwise The field won't be present.
   * The value returned may be {@code null}.
   */
  public Boolean getRestricted() {
    return restricted;
  }

  /**
   * Age-restricted trailers. For redband trailers and adult-rated video-games. Only users aged 18+
   * can view the content. The the field is true the content is restricted to viewers aged 18+.
   * Otherwise The field won't be present.
   * The value set may be {@code null}.
   */
  public VideoAgeGating setRestricted(Boolean restricted) {
    this.restricted = restricted;
    return this;
  }

  /**
   * Video game rating, if any.
   * The value returned may be {@code null}.
   */
  public String getVideoGameRating() {
    return videoGameRating;
  }

  /**
   * Video game rating, if any.
   * The value set may be {@code null}.
   */
  public VideoAgeGating setVideoGameRating(String videoGameRating) {
    this.videoGameRating = videoGameRating;
    return this;
  }

}
