/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Describes original video file properties, including technical details about audio and video
 * streams, but also metadata information like content length, digitization time, or geotagging
 * information.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoFileDetails extends GenericJson {

  /**
   * A list of audio streams contained in the uploaded video file. Each item in the list contains
   * detailed metadata about an audio stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<VideoFileDetailsAudioStream> audioStreams;

  static {
    // hack to force ProGuard to consider VideoFileDetailsAudioStream used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(VideoFileDetailsAudioStream.class);
  }

  /**
   * The uploaded video file's combined (video and audio) bitrate in bits per second.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong bitrateBps;

  /**
   * The uploaded video file's container format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String container;

  /**
   * The date and time when the uploaded video file was created. The value is specified in ISO 8601
   * format. Currently, the following ISO 8601 formats are supported: - Date only: YYYY-MM-DD  -
   * Naive time: YYYY-MM-DDTHH:MM:SS  - Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String creationTime;

  /**
   * The length of the uploaded video in milliseconds.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong durationMs;

  /**
   * The uploaded file's name. This field is present whether a video file or another type of file
   * was uploaded.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fileName;

  /**
   * The uploaded file's size in bytes. This field is present whether a video file or another type
   * of file was uploaded.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong fileSize;

  /**
   * The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube
   * only processes video files, but this field is present whether a video file or another type of
   * file was uploaded.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String fileType;

  /**
   * Geographic coordinates that identify the place where the uploaded video was recorded.
   * Coordinates are defined using WGS 84.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private GeoPoint recordingLocation;

  /**
   * A list of video streams contained in the uploaded video file. Each item in the list contains
   * detailed metadata about a video stream.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<VideoFileDetailsVideoStream> videoStreams;

  static {
    // hack to force ProGuard to consider VideoFileDetailsVideoStream used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(VideoFileDetailsVideoStream.class);
  }

  /**
   * A list of audio streams contained in the uploaded video file. Each item in the list contains
   * detailed metadata about an audio stream.
   * The value returned may be {@code null}.
   */
  public java.util.List<VideoFileDetailsAudioStream> getAudioStreams() {
    return audioStreams;
  }

  /**
   * A list of audio streams contained in the uploaded video file. Each item in the list contains
   * detailed metadata about an audio stream.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setAudioStreams(java.util.List<VideoFileDetailsAudioStream> audioStreams) {
    this.audioStreams = audioStreams;
    return this;
  }

  /**
   * The uploaded video file's combined (video and audio) bitrate in bits per second.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getBitrateBps() {
    return bitrateBps;
  }

  /**
   * The uploaded video file's combined (video and audio) bitrate in bits per second.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setBitrateBps(UnsignedLong bitrateBps) {
    this.bitrateBps = bitrateBps;
    return this;
  }

  /**
   * The uploaded video file's container format.
   * The value returned may be {@code null}.
   */
  public String getContainer() {
    return container;
  }

  /**
   * The uploaded video file's container format.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setContainer(String container) {
    this.container = container;
    return this;
  }

  /**
   * The date and time when the uploaded video file was created. The value is specified in ISO 8601
   * format. Currently, the following ISO 8601 formats are supported: - Date only: YYYY-MM-DD  -
   * Naive time: YYYY-MM-DDTHH:MM:SS  - Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM
   * The value returned may be {@code null}.
   */
  public String getCreationTime() {
    return creationTime;
  }

  /**
   * The date and time when the uploaded video file was created. The value is specified in ISO 8601
   * format. Currently, the following ISO 8601 formats are supported: - Date only: YYYY-MM-DD  -
   * Naive time: YYYY-MM-DDTHH:MM:SS  - Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM
   * The value set may be {@code null}.
   */
  public VideoFileDetails setCreationTime(String creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  /**
   * The length of the uploaded video in milliseconds.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getDurationMs() {
    return durationMs;
  }

  /**
   * The length of the uploaded video in milliseconds.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setDurationMs(UnsignedLong durationMs) {
    this.durationMs = durationMs;
    return this;
  }

  /**
   * The uploaded file's name. This field is present whether a video file or another type of file
   * was uploaded.
   * The value returned may be {@code null}.
   */
  public String getFileName() {
    return fileName;
  }

  /**
   * The uploaded file's name. This field is present whether a video file or another type of file
   * was uploaded.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setFileName(String fileName) {
    this.fileName = fileName;
    return this;
  }

  /**
   * The uploaded file's size in bytes. This field is present whether a video file or another type
   * of file was uploaded.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getFileSize() {
    return fileSize;
  }

  /**
   * The uploaded file's size in bytes. This field is present whether a video file or another type
   * of file was uploaded.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setFileSize(UnsignedLong fileSize) {
    this.fileSize = fileSize;
    return this;
  }

  /**
   * The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube
   * only processes video files, but this field is present whether a video file or another type of
   * file was uploaded.
   * The value returned may be {@code null}.
   */
  public String getFileType() {
    return fileType;
  }

  /**
   * The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube
   * only processes video files, but this field is present whether a video file or another type of
   * file was uploaded.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setFileType(String fileType) {
    this.fileType = fileType;
    return this;
  }

  /**
   * Geographic coordinates that identify the place where the uploaded video was recorded.
   * Coordinates are defined using WGS 84.
   * The value returned may be {@code null}.
   */
  public GeoPoint getRecordingLocation() {
    return recordingLocation;
  }

  /**
   * Geographic coordinates that identify the place where the uploaded video was recorded.
   * Coordinates are defined using WGS 84.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setRecordingLocation(GeoPoint recordingLocation) {
    this.recordingLocation = recordingLocation;
    return this;
  }

  /**
   * A list of video streams contained in the uploaded video file. Each item in the list contains
   * detailed metadata about a video stream.
   * The value returned may be {@code null}.
   */
  public java.util.List<VideoFileDetailsVideoStream> getVideoStreams() {
    return videoStreams;
  }

  /**
   * A list of video streams contained in the uploaded video file. Each item in the list contains
   * detailed metadata about a video stream.
   * The value set may be {@code null}.
   */
  public VideoFileDetails setVideoStreams(java.util.List<VideoFileDetailsVideoStream> videoStreams) {
    this.videoStreams = videoStreams;
    return this;
  }

}
