/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Information about a video stream.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoFileDetailsVideoStream extends GenericJson {

  /**
   * The video content's display aspect ratio, which specifies the aspect ratio in which the video
   * should be displayed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double aspectRatio;

  /**
   * The video stream's bitrate, in bits per second.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong bitrateBps;

  /**
   * The video codec that the stream uses.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String codec;

  /**
   * The video stream's frame rate, in frames per second.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Double frameRateFps;

  /**
   * The encoded video content's height in pixels.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long heightPixels;

  /**
   * The amount that YouTube needs to rotate the original source content to properly display the
   * video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String rotation;

  /**
   * A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor
   * code.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String vendor;

  /**
   * The encoded video content's width in pixels. You can calculate the video's encoding aspect
   * ratio as width_pixels / height_pixels.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Long widthPixels;

  /**
   * The video content's display aspect ratio, which specifies the aspect ratio in which the video
   * should be displayed.
   * The value returned may be {@code null}.
   */
  public Double getAspectRatio() {
    return aspectRatio;
  }

  /**
   * The video content's display aspect ratio, which specifies the aspect ratio in which the video
   * should be displayed.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setAspectRatio(Double aspectRatio) {
    this.aspectRatio = aspectRatio;
    return this;
  }

  /**
   * The video stream's bitrate, in bits per second.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getBitrateBps() {
    return bitrateBps;
  }

  /**
   * The video stream's bitrate, in bits per second.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setBitrateBps(UnsignedLong bitrateBps) {
    this.bitrateBps = bitrateBps;
    return this;
  }

  /**
   * The video codec that the stream uses.
   * The value returned may be {@code null}.
   */
  public String getCodec() {
    return codec;
  }

  /**
   * The video codec that the stream uses.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setCodec(String codec) {
    this.codec = codec;
    return this;
  }

  /**
   * The video stream's frame rate, in frames per second.
   * The value returned may be {@code null}.
   */
  public Double getFrameRateFps() {
    return frameRateFps;
  }

  /**
   * The video stream's frame rate, in frames per second.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setFrameRateFps(Double frameRateFps) {
    this.frameRateFps = frameRateFps;
    return this;
  }

  /**
   * The encoded video content's height in pixels.
   * The value returned may be {@code null}.
   */
  public Long getHeightPixels() {
    return heightPixels;
  }

  /**
   * The encoded video content's height in pixels.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setHeightPixels(Long heightPixels) {
    this.heightPixels = heightPixels;
    return this;
  }

  /**
   * The amount that YouTube needs to rotate the original source content to properly display the
   * video.
   * The value returned may be {@code null}.
   */
  public String getRotation() {
    return rotation;
  }

  /**
   * The amount that YouTube needs to rotate the original source content to properly display the
   * video.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setRotation(String rotation) {
    this.rotation = rotation;
    return this;
  }

  /**
   * A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor
   * code.
   * The value returned may be {@code null}.
   */
  public String getVendor() {
    return vendor;
  }

  /**
   * A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor
   * code.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setVendor(String vendor) {
    this.vendor = vendor;
    return this;
  }

  /**
   * The encoded video content's width in pixels. You can calculate the video's encoding aspect
   * ratio as width_pixels / height_pixels.
   * The value returned may be {@code null}.
   */
  public Long getWidthPixels() {
    return widthPixels;
  }

  /**
   * The encoded video content's width in pixels. You can calculate the video's encoding aspect
   * ratio as width_pixels / height_pixels.
   * The value set may be {@code null}.
   */
  public VideoFileDetailsVideoStream setWidthPixels(Long widthPixels) {
    this.widthPixels = widthPixels;
    return this;
  }

}
