/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.common.primitives.UnsignedLong;

/**
 * Video processing progress and completion time estimate.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoProcessingDetailsProcessingProgress extends GenericJson {

  /**
   * The number of parts of the video that YouTube has already processed. You can estimate the
   * percentage of the video that YouTube has already processed by calculating: 100 *
   * parts_processed / parts_total
   *
   * Note that since the estimated number of parts could increase without a corresponding increase
   * in the number of parts that have already been processed, it is possible that the calculated
   * progress could periodically decrease while YouTube processes a video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong partsProcessed;

  /**
   * An estimate of the total number of parts that need to be processed for the video. The number
   * may be updated with more precise estimates while YouTube processes the video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong partsTotal;

  /**
   * An estimate of the amount of time, in millseconds, that YouTube needs to finish processing the
   * video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private UnsignedLong timeLeftMs;

  /**
   * The number of parts of the video that YouTube has already processed. You can estimate the
   * percentage of the video that YouTube has already processed by calculating: 100 *
   * parts_processed / parts_total
   *
   * Note that since the estimated number of parts could increase without a corresponding increase
   * in the number of parts that have already been processed, it is possible that the calculated
   * progress could periodically decrease while YouTube processes a video.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getPartsProcessed() {
    return partsProcessed;
  }

  /**
   * The number of parts of the video that YouTube has already processed. You can estimate the
   * percentage of the video that YouTube has already processed by calculating: 100 *
   * parts_processed / parts_total
   *
   * Note that since the estimated number of parts could increase without a corresponding increase
   * in the number of parts that have already been processed, it is possible that the calculated
   * progress could periodically decrease while YouTube processes a video.
   * The value set may be {@code null}.
   */
  public VideoProcessingDetailsProcessingProgress setPartsProcessed(UnsignedLong partsProcessed) {
    this.partsProcessed = partsProcessed;
    return this;
  }

  /**
   * An estimate of the total number of parts that need to be processed for the video. The number
   * may be updated with more precise estimates while YouTube processes the video.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getPartsTotal() {
    return partsTotal;
  }

  /**
   * An estimate of the total number of parts that need to be processed for the video. The number
   * may be updated with more precise estimates while YouTube processes the video.
   * The value set may be {@code null}.
   */
  public VideoProcessingDetailsProcessingProgress setPartsTotal(UnsignedLong partsTotal) {
    this.partsTotal = partsTotal;
    return this;
  }

  /**
   * An estimate of the amount of time, in millseconds, that YouTube needs to finish processing the
   * video.
   * The value returned may be {@code null}.
   */
  public UnsignedLong getTimeLeftMs() {
    return timeLeftMs;
  }

  /**
   * An estimate of the amount of time, in millseconds, that YouTube needs to finish processing the
   * video.
   * The value set may be {@code null}.
   */
  public VideoProcessingDetailsProcessingProgress setTimeLeftMs(UnsignedLong timeLeftMs) {
    this.timeLeftMs = timeLeftMs;
    return this;
  }

}
