/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.youtube.model;

import com.google.api.client.json.GenericJson;

/**
 * Basic details about a video category, such as its localized title.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the YouTube Data API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class VideoStatus extends GenericJson {

  /**
   * This value indicates if the video can be embedded on another website.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean embeddable;

  /**
   * This value explains why a video failed to upload. This property is only present if the
   * uploadStatus property indicates that the upload failed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String failureReason;

  /**
   * The video's license.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String license;

  /**
   * The video's privacy status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String privacyStatus;

  /**
   * This value indicates if the extended video statistics on the watch page can be viewed by
   * everyone. Note that the view count, likes, etc will still be visible if this is disabled.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean publicStatsViewable;

  /**
   * This value explains why YouTube rejected an uploaded video. This property is only present if
   * the uploadStatus property indicates that the upload was rejected.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String rejectionReason;

  /**
   * The status of the uploaded video.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String uploadStatus;

  /**
   * This value indicates if the video can be embedded on another website.
   * The value returned may be {@code null}.
   */
  public Boolean getEmbeddable() {
    return embeddable;
  }

  /**
   * This value indicates if the video can be embedded on another website.
   * The value set may be {@code null}.
   */
  public VideoStatus setEmbeddable(Boolean embeddable) {
    this.embeddable = embeddable;
    return this;
  }

  /**
   * This value explains why a video failed to upload. This property is only present if the
   * uploadStatus property indicates that the upload failed.
   * The value returned may be {@code null}.
   */
  public String getFailureReason() {
    return failureReason;
  }

  /**
   * This value explains why a video failed to upload. This property is only present if the
   * uploadStatus property indicates that the upload failed.
   * The value set may be {@code null}.
   */
  public VideoStatus setFailureReason(String failureReason) {
    this.failureReason = failureReason;
    return this;
  }

  /**
   * The video's license.
   * The value returned may be {@code null}.
   */
  public String getLicense() {
    return license;
  }

  /**
   * The video's license.
   * The value set may be {@code null}.
   */
  public VideoStatus setLicense(String license) {
    this.license = license;
    return this;
  }

  /**
   * The video's privacy status.
   * The value returned may be {@code null}.
   */
  public String getPrivacyStatus() {
    return privacyStatus;
  }

  /**
   * The video's privacy status.
   * The value set may be {@code null}.
   */
  public VideoStatus setPrivacyStatus(String privacyStatus) {
    this.privacyStatus = privacyStatus;
    return this;
  }

  /**
   * This value indicates if the extended video statistics on the watch page can be viewed by
   * everyone. Note that the view count, likes, etc will still be visible if this is disabled.
   * The value returned may be {@code null}.
   */
  public Boolean getPublicStatsViewable() {
    return publicStatsViewable;
  }

  /**
   * This value indicates if the extended video statistics on the watch page can be viewed by
   * everyone. Note that the view count, likes, etc will still be visible if this is disabled.
   * The value set may be {@code null}.
   */
  public VideoStatus setPublicStatsViewable(Boolean publicStatsViewable) {
    this.publicStatsViewable = publicStatsViewable;
    return this;
  }

  /**
   * This value explains why YouTube rejected an uploaded video. This property is only present if
   * the uploadStatus property indicates that the upload was rejected.
   * The value returned may be {@code null}.
   */
  public String getRejectionReason() {
    return rejectionReason;
  }

  /**
   * This value explains why YouTube rejected an uploaded video. This property is only present if
   * the uploadStatus property indicates that the upload was rejected.
   * The value set may be {@code null}.
   */
  public VideoStatus setRejectionReason(String rejectionReason) {
    this.rejectionReason = rejectionReason;
    return this;
  }

  /**
   * The status of the uploaded video.
   * The value returned may be {@code null}.
   */
  public String getUploadStatus() {
    return uploadStatus;
  }

  /**
   * The status of the uploaded video.
   * The value set may be {@code null}.
   */
  public VideoStatus setUploadStatus(String uploadStatus) {
    this.uploadStatus = uploadStatus;
    return this;
  }

}
